<?php

// Norwegian language include
// For version 2.0 PHP iCalendar
//
// Translation by Eirik Wulff (eirik@wulff.biz)
//
// Submit new translations to chad@chadsdomain.com

$lang['l_day'] 				= 'Dag';
$lang['l_week'] 			= 'Uke';
$lang['l_month'] 			= 'M&aring;ned';
$lang['l_year'] 			= '&Aring;r';
$lang['l_calendar'] 		= 'Kalender';
$lang['l_next_day'] 		= 'Neste dag';
$lang['l_next_month'] 		= 'Neste m&aring;ned';
$lang['l_next_week'] 		= 'Neste uke';
$lang['l_next_year'] 		= 'Neste &aring;r';
$lang['l_last_day'] 		= 'Forrige dag';
$lang['l_last_month'] 		= 'Forrige m&aring;ned';
$lang['l_last_week'] 		= 'Forrige uke';
$lang['l_last_year'] 		= 'Forrige &aring;r';
$lang['l_subscribe'] 		= 'Abonner';
$lang['l_download'] 		= 'Last ned';
$lang['l_powered_by'] 		= 'Kj&oslash;res med';
$lang['l_event'] 			= 'Hendelse';
$lang['l_event_start'] 		= 'Starttid';
$lang['l_event_end'] 		= 'End Time';
$lang['l_this_months'] 		= 'Hendelser denne m&aring;neden';
$lang['l_date'] 			= 'Dato';
$lang['l_summary'] 			= 'Sammendrag';
$lang['l_all_day'] 			= 'Heldagshendelse';
$lang['l_notes'] 			= 'Notater';
$lang['l_this_years'] 		= 'Hendelser dette &aring;ret';
$lang['l_today'] 			= 'I dag';
$lang['l_this_week'] 		= 'Denne uka';
$lang['l_this_month'] 		= 'Denne m&aring;neden';
$lang['l_jump'] 			= 'G&aring; til';
$lang['l_tomorrows'] 		= 'Morgendagens hendelser';
$lang['l_goday'] 			= 'Vis dagen i dag';
$lang['l_goweek'] 			= 'Vis denne uka';
$lang['l_gomonth'] 			= 'Vis denne m&aring;neden';
$lang['l_goyear'] 			= 'Vis dette &aring;ret';
$lang['l_search'] 			= 'S&oslash;k'; // the verb
$lang['l_results'] 			= 'S&oslash;keresultater';
$lang['l_pick_multiple'] 	= 'Pick multiple';
$lang['l_query'] 			= 'Foresp&oslash;rsel: '; // will be followed by the search query
$lang['l_no_results'] 		= 'Ingen hendelser';
$lang['l_goprint'] 			= 'Utskriftsvennlig';
$lang['l_time'] 			= 'Tid';
$lang['l_summary'] 			= 'Oppsummering';
$lang['l_description'] 		= 'Beskrivelse';
$lang['l_this_site_is']		= 'Dette webstedet er';
$lang['l_no_events_day']	= 'Ingen hendelser i dag.';
$lang['l_no_events_week']	= 'Ingen hendelser denne uka.';
$lang['l_no_events_month']	= 'Ingen hendelser denne m&aring;neden.';
$lang['l_rss_day_date']		= 'g:i A';  // Lists just the time
$lang['l_rss_week_date	']	= '%b %e';  // Lists just the day
$lang['l_rss_month_date	']	= '%b %e';  // Lists just the day
$lang['l_rss_language']		= 'en-us';
$lang['l_search_took']		= 'S&oslash;ket ti %s sekunder';
$lang['l_recurring_event']	= 'Repeterende hendelse';
$lang['l_exception']		= 'Unntak';
$lang['l_no_query']			= 'Ingen foresp&oslash;rsel oppgitt';
$lang['l_preferences']		= 'Valg';
$lang['l_printer']			= 'Skriver';
$lang['l_select_lang']		= 'Velg spr&aring;k';
$lang['l_select_cal']		= 'Velg standardkalender';
$lang['l_select_view']		= 'Velg standardvisning';
$lang['l_select_time']		= 'Velg standard starttid';
$lang['l_select_day']		= 'Uken starter p&aring;';
$lang['l_select_style']		= 'Velg visningsstil';
$lang['l_set_prefs']		= 'Lagre valg';
$lang['l_completed_date']	= 'Ferdig p&aring;';
$lang['l_completed']		= 'Ferdig';
$lang['l_created']			= 'Opprettet';
$lang['l_due']				= 'Forfall';
$lang['l_priority']			= 'Prioritet';
$lang['l_priority_high']	= 'H&oslash;y';
$lang['l_priority_low']		= 'Lav';
$lang['l_priority_medium']	= 'Medium';
$lang['l_priority_none']	= 'Ingen';
$lang['l_status']			= 'Status';
$lang['l_status_confirmed'] = 'CONFIRMED' ; 
$lang['l_status_cancelled'] = 'CANCELLED'; 
$lang['l_status_tentative'] = 'TENTATIVE'; 
$lang['l_todo']				= 'Oppgaver';
$lang['l_unfinished']		= 'Uferdig';
$lang['l_prefs_set'] 		= 'Valgene dine har blitt lagret.';
$lang['l_prefs_unset'] 		= 'Valgene ble nullstilte. Endringer vises ved neste nedlasting av siden.';
$lang['l_unset_prefs'] 		= 'Nullstill valg';
$lang['l_organizer']		= 'Organisator';
$lang['l_attendee']			= 'Deltaker';
$lang['l_status']			= 'Status';
$lang['l_location']			= 'Sted';
$lang['l_admin_header']		= 'Administrasjon for PHP iCalendar';
$lang['l_username']			= 'Brukernavn';
$lang['l_password']			= 'Passord';
$lang['l_login']			= 'Logg inn';
$lang['l_invalid_login']	= 'Feil i brukernavn/passord.';
$lang['l_addupdate_cal']	= 'Legg til eller oppdater kalender';
$lang['l_addupdate_desc']	= 'Legg til ny kalender ved &aring; laste opp en ny fil. Oppdater en eksisterende ved &aring; laste opp ny fil med samme navn.';
$lang['l_delete_cal']		= 'Slett kalender';
$lang['l_logout']			= 'Logg ut';
$lang['l_cal_file']			= 'Kalenderfil';
$lang['l_php_error']		= 'PHP-feil';
$upload_error_gen_lang		= 'Problemer med opplastingen.';
$upload_error_lang[0]		= 'Vi fikk problemer med opplastingen.';
$upload_error_lang[1]		= 'Filen du laster opp er for stor.';
$upload_error_lang[2]		= 'Filen du laster opp er for stor.';
$upload_error_lang[3]		= 'Filen du pr&oslash;er &aring; lasste opp ble bare delvis lastet.';
$upload_error_lang[4]		= 'Du m&aring; velge en fil &aring; laste opp.';
$lang['l_upload_error_type'] = 'Kun .ics-filer kan lastes opp.';
$lang['l_copy_error']			= 'Kunne ikke kopiere fila';
$lang['l_delete_error']			= 'Kunne ikke slette fila';
$lang['l_delete_success']		= 'ble slettet.';
$lang['l_action_success']		= 'Handlingen ble utf&oslash;rt.';
$lang['l_submit']				= 'Legg inn';
$lang['l_delete']				= 'Slett';
$all_cal_comb_lang			= 'Alle kalendere samlet';

// New for 2.0
$lang['l_legend']			= 'Kalendere';
$lang['l_admin_subhead']	= 'Styr kalenderne fra denne siden';
$lang['l_prefs_subhead']	= 'Setter en informasjonskapsel for &aring; lagre oppsettet';
$lang['l_rss_info']			= 'RSS-informasjon';
$lang['l_rss_subhead']		= 'RSS-str&oslash;mmer er tilgjengelige for hver kalender';
$lang['l_rss_notenabled']	= 'RSS er ikke tilgjengelig';

// - navigation
$lang['l_back'] 		= 'Tilbake';
$lang['l_next'] 		= 'Neste';
$lang['l_prev'] 		= 'Forrige';
$lang['l_day_view'] 	= 'Dagsvisning';
$lang['l_week_view'] 	= 'Ukevisning';
$lang['l_month_view'] 	= 'M&aring;nedsvisning';
$lang['l_year_view'] 	= '&Aring;rsvisning';

// ---------------------------------


// $format_recur, items enclosed in % will be substituted with variables
$format_recur_lang['delimiter']	= ', ';								// ie, 'one, two, three'

$format_recur_lang['yearly']		= array('&aring;r','&aring;rlig');		// for these, put singular
$format_recur_lang['monthly']		= array('m&aring;ned','m&aring;neder');		// and plural forms
$format_recur_lang['weekly']		= array('uke','uker');		// these will be %freq%
$format_recur_lang['daily']			= array('dag','dager');			// in the replacement below
$format_recur_lang['hourly']		= array('time','timer');
$format_recur_lang['minutely']		= array('minutt','minutter');
$format_recur_lang['secondly']		= array('sekund','sekunder');

$format_recur_lang['start']			= 'Hver %int% %freq% %for%';	// ie, 'Every 1 day until January 4' or 'Every 1 day for a count of 5'
$format_recur_lang['until']			= 'til %date%';				// ie, 'until January 4'
$format_recur_lang['count']			= 'for et antall av %int%';		// ie, 'for 5 times'

$format_recur_lang['bymonth']		= 'I m&aring;neder: %list%';			// ie, 'In months: January, February, March'
$format_recur_lang['bymonthday']	= 'P&aring; datoene: %list%';			// ie, 'On dates: 1, 2, 3, 4'
$format_recur_lang['byday']			= 'P&aring; dagene: %list%';			// ie, 'On days: Mon, Tues, Wed, Thurs'

// ---------------------------------

$daysofweek_lang			= array('s&oslash;ndag','mandag','tirsdag','onsdag','torsdag','fredag','l&oslash;rdag');
$daysofweekshort_lang		= array ('s&oslash;n','man','tir','ons','tor','fre','l&oslash;r');
$daysofweekreallyshort_lang	= array ('S','M','T','O','T','F','L');
$monthsofyear_lang			= array ('januar','februar','mars','april','mai','juni','juli','august','september','oktober','november','desember');
$monthsofyearshort_lang		= array ('jan','feb','mar','apr','mai','jun','jul','aug','sep','okt','nov','des');

// For time formatting, check out: http://www.php.net/manual/en/function.date.php
$timeFormat = 'H:i';
$timeFormat_small = 'H:i';

// For date formatting, see note below
$dateFormat_day = '%A %e. %B ';
$dateFormat_week = '%e. %B';
$dateFormat_week_list = '%a %e. %b';
$dateFormat_week_jump = '%b %e';
$dateFormat_month = '%B %Y';
$dateFormat_month_list = '%A %e. %B';
$dateFormat_year = '%Y';

/*
Notes about dateFormat_*
	The pieces are similar to that of the PHP function strftime(), 
	however only the following is supported at this time:
	
	%A - the full week day name as specified in $daysofweek_lang
	%a - the shortened week day name as specified in $daysofweekshort_lang
	%B - the full month name as specified in $monthsofyear_lang
	%b - the shortened month name as specified in $monthsofyearshort_lang
	%e - the day of the month as a decimal number (1 to 31)
	%Y - the 4-digit year

	If this causes problems with representing your language accurately, let
	us know. We will be happy to modify this if needed.
*/

// Error messages - %s will be replaced with a variable
$lang['l_error_title'] 			= 'Feil!';
$lang['l_error_window'] 		= 'En feil oppsto!';
$lang['l_error_calendar'] 		= 'Kalenderen "%s" var i bruk da feilen oppsto.';
$lang['l_error_path'] 			= 'Kan ikke &aring;pne stien "%s"';
$lang['l_error_back'] 			= 'Bruk "Tilbake"-knappen for &aring; g&aring; tilbake.';
$lang['l_error_remotecal'] 		= 'Denne tjeneren sperrer ikke-lokale kalendere som ikke har blitt godkjent.';
$lang['l_error_restrictedcal'] 	= 'Du pr&oslash;ver &aring; &aring;pne en kalender som har begrenset tilgang.';
$lang['l_error_invalidcal'] 	= 'Ugyldig kalenderfil. Pr&oslash;v en anenn kalender.';
$lang['l_error_cantopen'] 		= 'Kunne ikke &aring;pne kalenderfila.';
$lang['l_error_cache']			= 'Klarer ikke &aring; skrive til cache-mappen. Sjekk oppsettet p&aring; webstedet.';

?>
